Supvisors status

| Name | State | Description | Load | CPU | MEM | Actions | Log
--- | --- | --- | --- | --- | --- | --- | --- | ---
Name | State | Description | Load | CPU | MEM | Actions | Log
TOTAL | -- | -- | -- |
| Name | State | Description | -- | -- | -- | Start | Stop | Restart | Clear | Stdout | Stderr

#### Detailed Statistics -- *

CPU
% | Mean % | Slope % | SD %
--- | --- | --- | ---
-- | -- | -- | --

MEM
% | Mean % | Slope % | SD %
--- | --- | --- | ---
-- | -- | -- | --